@@ -14,8 +14,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
 import os
 import pwd
 import sys
@@ -24,7 +22,7 @@ import socket
 import time
 import urllib.request as urllib2
 from urllib.error import URLError
-from .function import _print, get_ip_mac_type
+from .function import _print, get_ip_mac_type, parse_error
 import OpenSSL
 import hashlib
 from .client_class import HTTPSClientCertTransport
@@ -109,7 +107,7 @@ def new_key_req(key, cert_path, server_host_name, private_key_passwd=None,
     crtreq = req.as_pem()
 
     req_file = cert_path + '/%s.csr' % server_host_name
-    crtfile = open(req_file, 'w')
+    crtfile = open(req_file, 'wb')
     crtfile.write(crtreq)
     crtfile.close()
 
@@ -117,7 +115,7 @@ def new_key_req(key, cert_path, server_host_name, private_key_passwd=None,
     try:
         pwdObj = pwd.getpwnam(user_name)
     except KeyError as e:
-        _print(e)
+        _print(parse_error(e))
         return None
     os.chown(key, pwdObj.pw_uid, pwdObj.pw_gid)
     os.chmod(key, 0o600)
@@ -132,14 +130,14 @@ def delete_old_cert(client):
         os.unlink(client.PKEY_FILE)
         os.unlink(client.PubKEY_FILE)
     except OSError as e:
-        _print(e)
+        _print(parse_error(e))
 
 
 def client_post_request(cert_path, args):
     if os.path.exists(cert_path + 'req_id'):
         print(_("You already sent a certificate signature request."))
         _print(_("Request ID = %s") % readFile(cert_path + 'req_id'))
-        ans = raw_input(_("Send a new request? y/[n]: "))
+        ans = input(_("Send a new request? y/[n]: "))
         if not ans.lower() in ['y', 'yes']:
             return 0
     clVars = DataVarsCore()
@@ -167,7 +165,7 @@ def client_post_request(cert_path, args):
     csr_file = os.path.join(cert_path, server_host_name + '.csr')
     if os.path.exists(key) and os.path.exists(csr_file):
         print(_("the private key and request now exist"))
-        ask = raw_input(_("Create a new private key and request? y/[n]: "))
+        ask = input(_("Create a new private key and request? y/[n]: "))
         if ask.lower() in ['y', 'yes']:
             passwd = get_password()
             new_key_req(key, cert_path, server_host_name,
@@ -227,9 +225,9 @@ def client_get_cert(cert_path, args):
         print(_("Request %s not found on the client's side") \
               % (os.path.join(cert_path, server_host_name + '.csr')))
         return 1
-    request = readFile(os.path.join(cert_path, server_host_name + '.csr'))
+    request = readFile(os.path.join(cert_path, server_host_name + '.csr'), binary=True)
     md5 = hashlib.md5()
-    md5.update(request.encode("UTF-8"))
+    md5.update(request)
     md5sum = md5.hexdigest()
 
     result = client.service.get_client_cert(req_id, md5sum)
@@ -260,13 +258,13 @@ def client_get_cert(cert_path, args):
     try:
         os.unlink(cert_path + 'req_id')
     except OSError as e:
-        _print(e)
+        _print(parse_error(e))
     print(_('Certificate saved. Your certificate ID: %s') % req_id)
     user_name = pwd.getpwuid(os.getuid()).pw_name
     try:
         pwdObj = pwd.getpwnam(user_name)
     except KeyError as e:
-        _print(e)
+        _print(parse_error(e))
         return None
     os.chown(cert_file, pwdObj.pw_uid, pwdObj.pw_gid)
     os.chmod(cert_file, 0o600)
@@ -307,8 +305,8 @@ def client_get_cert(cert_path, args):
                 (OpenSSL.SSL.FILETYPE_PEM, ca_root)
             Issuer = certobj.get_issuer().get_components()
             for item in Issuer:
-                if item[0] == 'CN':
-                    filename = item[1]
+                if item[0] == b'CN':
+                    filename = item[1].decode("UTF-8")
 
             fc = open(root_cert_md5, "a")
             fc.write('%s %s\n' % (md5sum, filename))
@@ -401,7 +399,7 @@ def create_socket(file_path, username):
         try:
             os.unlink(file_path)
         except OSError as e:
-            _print(e)
+            _print(parse_error(e))
 
         cmd = ['cl-consoled']
         # print cmd
