@@ -13,8 +13,6 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-from __future__ import print_function
-from __future__ import absolute_import
 from calculate.core.server.local_call import Display, Methods, has_force_arg
 from calculate.lib.utils.tools import unpack_single_opts
 
@@ -43,7 +41,7 @@ from calculate.core.datavars import DataVarsCore
 from .client_class import HTTPSClientCertTransport
 from .methods_func import call_method, get_method_argparser, parse, get_view
 from .function import (MessageReceiver, MessageDispatcher, clear, _print,
-                      get_view_params)
+                      get_view_params, parse_error)
 from calculate.lib.utils.files import makeDirectory, readLinesFile
 from calculate.lib.cl_lang import setLocalTranslate
 
@@ -310,7 +308,7 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
                 mr.analysis(method_result)
                 # analysis(client, client.sid, method_result)
             except URLError as e:
-                _print(e)
+                _print(parse_error(e))
             except KeyboardInterrupt:
                 try:
                     print()
@@ -327,7 +325,7 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
                         print(_("Failed to terminate the process"))
                     mr.analysis(method_result)
                 except Exception as e:
-                    _print(e)
+                    _print(parse_error(e))
 
             try:
                 mess = method_result[0][0]
